get_real_dfr: Create real terms series from columns in a dataframe given a...

Description Usage

View source: R/deflators.R

Description

This is the raw version of get_real. It should only be used internally within the package inside functions which provide validation.

Usage

1
get_real_dfr(data, deflator, from = 2, to = ncol(data), baserow = nrow(data))

houseofcommonslibrary/cltools documentation built on Sept. 18, 2020, 12:55 p.m.